from src import mzx


def test_modify_waters_scan_header():
    input_str = '        <spectrum index="0" id="function=1 process=0 scan=1" defaultArrayLength="3510" dataProcessingRef="pwiz_Reader_Waters_conversion">'  # noqa: E501
    expected_output = '        <spectrum index="0" id="function=1 process=0 scan=1 fscan=1" defaultArrayLength="3510" dataProcessingRef="pwiz_Reader_Waters_conversion">'  # noqa: E501

    output_string = mzx.modify_waters_scan_header(input_str)

    assert output_string == expected_output



import loguru
import subprocess


def check_running() -> bool:
    """
    Check if Docker is running by executing the `docker info` command.

    Returns:
        bool: True if Docker is running (command succeeded), False otherwise.
    """
    try:
        subprocess.run(
            ["docker", "info"],
            check=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
        )
        return True
    except subprocess.CalledProcessError as e:
        loguru.logger.exception(e)
        return False



import mock
import subprocess
from src.mzx import docker  # Adjust to your module's path


@mock.patch("src.mzx.docker.subprocess.run", return_value=None)
def test_docker_running(mock_run):
    """Test the case where Docker is running successfully."""
    result = docker.check_running()

    mock_run.assert_called_once_with(
        ["docker", "info"], check=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
    )
    assert result is True


@mock.patch("src.mzx.docker.subprocess.run")
def test_docker_not_running(mock_run):
    """Test the case where Docker is not running and command fails."""
    # Mock subprocess.run to raise CalledProcessError to simulate failure
    mock_run.side_effect = subprocess.CalledProcessError(1, ["docker", "info"])

    result = docker.check_running()

    mock_run.assert_called_once_with(
        ["docker", "info"], check=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
    )
    assert result is False
